#!/bin/sh
export PATH='/usr/lib/llvm15/bin/:/usr/lib/ccache/bin:/usr/bin'
printf '%s' 'name:                 semigroupoids
version:              6.0.0.1
visibility:           public
id:                   semigroupoids-6.0.0.1-GNMyzRGgqm52bj9jptOAIB
key:                  semigroupoids-6.0.0.1-GNMyzRGgqm52bj9jptOAIB
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/semigroupoids
synopsis:             Semigroupoids: Category sans id
description:
    Provides a wide array of (semi)groupoids and operations for working with them.

    A '\''Semigroupoid'\'' is a '\''Category'\'' without the requirement of identity arrows for every object in the category.

    A '\''Category'\'' is any '\''Semigroupoid'\'' for which the Yoneda lemma holds.

    When working with comonads you often have the @\<*\>@ portion of an @Applicative@, but
    not the @pure@. This was captured in Uustalu and Vene'\''s \"Essence of Dataflow Programming\"
    in the form of the @ComonadZip@ class in the days before @Applicative@. Apply provides a weaker invariant, but for the comonads used for data flow programming (found in the streams package), this invariant is preserved. Applicative function composition forms a semigroupoid.

    Similarly many structures are nearly a comonad, but not quite, for instance lists provide a reasonable '\''extend'\'' operation in the form of '\''tails'\'', but do not always contain a value.

    We describe the relationships between the type classes defined in this package
    and those from `base` (and some from `contravariant`) in the diagram below.
    Thick-bordered nodes correspond to type classes defined in this package;
    thin-bordered ones correspond to type classes from elsewhere. Solid edges
    indicate a subclass relationship that actually exists; dashed edges indicate a
    subclass relationship that /should/ exist, but currently doesn'\''t.

    <<https://raw.githubusercontent.com/ekmett/semigroupoids/master/img/classes.svg Relationships among type classes from this package and others>>

    Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.

    This lets us remove many of the restrictions from various monad transformers
    as in many cases the binding operation or @\<*\>@ operation does not require them.

    Finally, to work with these weaker structures it is beneficial to have containers
    that can provide stronger guarantees about their contents, so versions of '\''Traversable'\''
    and '\''Foldable'\'' that can be folded with just a '\''Semigroup'\'' are added.

category:             Control, Comonads
abi:                  2ff1c196d405d26e6e7f23aae66ac7d4
exposed:              True
exposed-modules:
    Data.Bifunctor.Apply Data.Functor.Alt Data.Functor.Apply
    Data.Functor.Bind Data.Functor.Bind.Class Data.Functor.Bind.Trans
    Data.Functor.Contravariant.Conclude
    Data.Functor.Contravariant.Decide Data.Functor.Contravariant.Divise
    Data.Functor.Extend Data.Functor.Plus Data.Groupoid
    Data.Isomorphism Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Categorical Data.Semigroupoid.Dual
    Data.Semigroupoid.Ob Data.Semigroupoid.Static
    Data.Traversable.Instances Semigroupoids.Do

hidden-modules:       Semigroupoids.Internal
import-dirs:          /usr/lib/ghc-9.8.2/site-local/semigroupoids-6.0.0.1
library-dirs:         /usr/lib/ghc-9.8.2/site-local/semigroupoids-6.0.0.1
library-dirs-static:  /usr/lib/ghc-9.8.2/site-local/semigroupoids-6.0.0.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-9.8.2
data-dir:             /usr/share/x86_64-linux-ghc-9.8.2/semigroupoids-6.0.0.1
hs-libraries:         HSsemigroupoids-6.0.0.1-GNMyzRGgqm52bj9jptOAIB
depends:
    base-4.19.1.0-inplace base-orphans-0.9.1-2l55U7IiQEbBQj7Rpk4rdH
    bifunctors-5.6.2-BwJEHVBCec7K8po0blH047
    comonad-5.0.8-Hep62HmhIUd3x0Q4bKCaUN containers-0.6.8-inplace
    contravariant-1.5.5-Jd4yZqVQ0CIJ5SyE5IM1hH
    distributive-0.6.2.1-5kfxdhHVQRS4AIEXvdtIhn
    hashable-1.4.4.0-4FjbwRHK8slL7OrZ7pqlVV
    tagged-0.8.8-JGlGh2qwg4dHU2Nz3aNqAk
    template-haskell-2.21.0.0-inplace transformers-0.6.1.0-inplace
    transformers-compat-0.7.2-11D715JMFvOAvxTx89MI7D
    unordered-containers-0.2.20-GUwBPxO7Ljy8Kmoa5HHL0Q

haddock-interfaces:
    /usr/share/doc/x86_64-linux-ghc-9.8.2/semigroupoids-6.0.0.1/html/semigroupoids.haddock

haddock-html:
    /usr/share/doc/x86_64-linux-ghc-9.8.2/semigroupoids-6.0.0.1/html
' | '/usr/bin/ghc-pkg-9.8.2' 'update' '-' '--global' '--no-user-package-db' "$@"

